<?php
/**
 * Tattoo Designer functions and definitions
 *
 * @package Tattoo Designer
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'tattoodesigner_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function tattoodesigner_setup() {
	global $content_width;
	if ( ! isset( $content_width ) )
		$content_width = 680;

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( 'align-wide' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'wp-block-styles');
	add_theme_support( 'custom-header', array(
		'default-text-color' => false,
		'header-text' => false,
	) );
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 100,
		'flex-height' => true,
	) );
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'tattoo-designer' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	add_editor_style( 'editor-style.css' );
}
endif; // tattoodesigner_setup
add_action( 'after_setup_theme', 'tattoodesigner_setup' );

function tattoodesigner_the_breadcrumb() {
	if (!is_home()) {
		echo '<a class="text-decoration-none fw-light" href="';
		echo esc_url( home_url() );
		echo '">';
		bloginfo('name');
		echo "</a> <i class='fas fa-chevron-right fs-6'></i> ";
		if (is_category() || is_single()) {
			the_category(' , ');
			if (is_single()) {
				echo " <i class='fas fa-chevron-right fs-6'></i> ";
				the_title();
			}
		} elseif (is_page()) {
			echo '<span class="text-decoration-none fw-light">';
			echo the_title();
			echo '</span>';
		}
	}
}

function tattoodesigner_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'tattoo-designer' ),
		'description'   => __( 'Appears on blog page sidebar', 'tattoo-designer' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer One', 'tattoo-designer' ),
		'description'   => __( 'Appears on footer One', 'tattoo-designer' ),
		'id'            => 'footer-one',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title text-white fw-normal mb-4">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer Two', 'tattoo-designer' ),
		'description'   => __( 'Appears on footer Two', 'tattoo-designer' ),
		'id'            => 'footer-two',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title text-white fw-normal mb-4">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer Three', 'tattoo-designer' ),
		'description'   => __( 'Appears on footer Three', 'tattoo-designer' ),
		'id'            => 'footer-Three',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title text-white fw-normal mb-4">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer Four', 'tattoo-designer' ),
		'description'   => __( 'Appears on footer Four', 'tattoo-designer' ),
		'id'            => 'footer-Four',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title text-white fw-normal mb-4">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'tattoodesigner_widgets_init' );

function tattoodesigner_scripts() {
	wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri())."/css/bootstrap.css" );
	wp_enqueue_style( 'owl.carousel-css', esc_url(get_template_directory_uri())."/css/owl.carousel.css" );
	wp_enqueue_style( 'tattoo-designer-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'tattoo-designer-default', esc_url(get_template_directory_uri())."/css/default.css" );
	wp_enqueue_script( 'owl.carousel-js', esc_url(get_template_directory_uri()). '/js/owl.carousel.js', array('jquery') );
	wp_enqueue_script( 'bootstrap-js', esc_url(get_template_directory_uri()). '/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'tattoo-designer-theme', esc_url(get_template_directory_uri()) . '/js/theme.js' );
	wp_enqueue_script( 'jquery.superfish', esc_url(get_template_directory_uri()) . '/js/jquery.superfish.js' );
	wp_enqueue_style( 'font-awesome-css', esc_url(get_template_directory_uri())."/css/fontawesome-all.css" );
	wp_enqueue_style( 'tattoo-designer-block-style', esc_url( get_template_directory_uri() ).'/css/blocks.css' );
	wp_enqueue_style('tattoo-designer-style', get_stylesheet_uri(), array() );
		wp_style_add_data('tattoo-designer-style', 'rtl', 'replace');
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_style( 'tattoo-designer-Knewave', 'https://fonts.googleapis.com/css2?family=Knewave&display=swap');

	wp_enqueue_style( 'tattoo-designer-Roboto', 'https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,100;0,300;0,400;0,500;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900&display=swap');
}
add_action( 'wp_enqueue_scripts', 'tattoodesigner_scripts' );

// Footer Link
define('TATTOODESIGNER_FOOTER_LINK',__('https://theclassictemplates.com/themes/free-tattoo-designer-wordpress-theme/','tattoo-designer'));

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Sanitization Callbacks.
 */
require get_template_directory() . '/inc/sanitization-callbacks.php';

/**
 * Sanitization Callbacks.
 */
require get_template_directory() . '/inc/addon.php';


/**
 * Theme Info Page.
 */
// require get_template_directory() . '/inc/addon.php';

/**
 * PRO Button Link
 */
load_template( trailingslashit( get_template_directory() ) . 'inc/button-link/class-button-link.php' );

if ( ! function_exists( 'tattoodesigner_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 */
function tattoodesigner_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;
